/************************************************************************/
/*																		*/
/*	System		: 78K0/IB2 Fluorecent Ballast Evaluation Board			*/
/*				  (EZ-BLST-003)											*/
/*																		*/
/*	Function	: Constant defination									*/
/*																		*/
/*	CPU			: uPD78F0756											*/
/*																		*/
/*	Last Update	: 2009/08/10(MON)										*/
/*																		*/
/*	File name	: defination.h											*/
/*																		*/
/************************************************************************/

/*========================================================================
	PFC output control
========================================================================*/
#define		PFC_CYCLE_RESTART	10000-1		/* (value+1)/40[us] : restarting cycle time for TX0CR1 register value */
#define		PFC_ON_MAX			800-1		/* (value+1)/40[us] : maximum on-time to prevent unexpected failure */
#define		PFC_ON_STEP			1			/* (value)/40[us] : minimum step of on-time to control DC output voltage */

/*========================================================================
	Inverter control
========================================================================*/
/*----- dead time of inverter output -----*/
#define		INV_DEAD_TIME		80					/* (value)/40[us] : dead time for TX1CR0 & TX1CR2 register */

/*----- Lamp preheating -----*/
#define		INV_PREHEAT			1020				/* (value)/100[us] : cycle time */
#define		INV_DUTY1_PREHEAT	INV_PREHEAT/5-1		/* TX1CR1 register value */
#define		INV_DUTY2_PREHEAT	(INV_PREHEAT/5-1) + INV_DEAD_TIME	/* TX1CR2 register value */
#define		INV_CYCLE_PREHEAT	INV_PREHEAT*2/5-1	/* TX1CR3 register value */

/*----- Frequency sweep -----*/
#define		INV_SWEEP			20					/* (value)/100[us] : displacement cycle time */
#define		INV_DUTY_SWEEP		INV_SWEEP/5			/* displacement value of TX1CR1 & TX1CR2 register */
#define		INV_CYCLE_SWEEP		INV_SWEEP*2/5		/* displacement value of TX1CR1 register */

/*----- Minimum dimming -----*/
#define		INV_MIN				1060				/* (value)/100[us] : cycle time */
#define		INV_CYCLE_MIN		INV_MIN*2/5-1		/* TX1CR3 register value */

/*----- Maximum dimming -----*/
#define		INV_MAX				1220				/* (value)/100[us] : cycle time */
#define		INV_CYCLE_MAX		INV_MAX*2/5-1		/* TX1CR3 register value */

/*========================================================================
	A/D conversion
========================================================================*/
/*----- Element number of the array -----*/
#define		NUM_TOTAL_ADCH		4			/* Total A/D conversion channel */
#define		NUM_STEP_VACIN		32			/* Step of AC supply voltage in 10V increments */

/*----- A/D channel pointer -----*/
#define		VDCOUT				0			/* DC output voltage detection */
#define		LAMP				1			/* Lamp detection */
#define		VACIN				2			/* AC input voltage detection */
#define		VOLUME				3			/* Volume detection */

/*----- A/D channel value (ANIx) -----*/
#define		ADCH_VDCOUT			0			/* DC output voltage detection */
#define		ADCH_LAMP			4			/* Lamp detection */
#define		ADCH_VACIN			6			/* AC input voltage detection */
#define		ADCH_VOLUME			8			/* Volume detection */

/*----- A/D conversion result for DC output voltage -----*/
#define		AD_VDCOUT_HBSTART	190			/* (value)*2[V] : starting voltage of inverter output */
#define		AD_VDCOUT_IGNITION	190			/* (value)*2[V] : detection voltage of lamp ignition */
#define		AD_VDCOUT_MIN		209			/* (value)*2[V] : lower limit of target voltage */
#define		AD_VDCOUT_MAX		211			/* (value)*2[V] : upper limit of target voltage */
#define		AD_VDCOUT_OVER		240			/* (value)*2[V] : over voltage for emergency stop */

/*----- A/D conversion result for lamp connection detection -----*/
#define		AD_LAMP_DETECT		40			/* Border value to detect lamp connection */

/*----- A/D conversion result for volume level detection -----*/
#define		AD_VOLUME_OFF		32			/* Lamp off */
#define		AD_VOLUME_MIN		128			/* Dim to min from max level */
#define		AD_VOLUME_MAX		160			/* Dim to max from min level or ignite from lamp off */

/*----- AC supply voltage calculated from A/D conversion result -----*/
#define		VACIN_MIN			9			/* (value)*10+/-5[V] : lower limit of allowable AC supply voltage (85V) */
#define		VACIN_MAX			26			/* (value)*10+/-5[V] : upper limit of allowable AC supply voltage (265V) */

/*========================================================================
	System timer
========================================================================*/
#define		SYS_INTERVAL_TIME	49			/* (value)*0.2048[ms] : Interval time of system timer */

/*========================================================================
	Dimming process
========================================================================*/
/*----- Dimming mode -----*/
#define		DIM_OFF				0			/* Lamp off */
#define		DIM_IGNITION		1			/* Lamp ignition */
#define		DIM_MAX				2			/* Maximum dimming */
#define		DIM_MIN				3			/* Minimum dimming */

/*----- Dimming state for lamp ignition process -----*/
#define		STATE_OFF			0			/* Lamp off */
#define		STATE_BOOST			1			/* Boost DC output voltage */
#define		STATE_PREHEAT		2			/* Preheat lamp */
#define		STATE_SWEEP			3			/* Sweep inverter frequency for lamp ignition */
#define		STATE_LIGHTING		4			/* Keep lighting to wait stable lighting */
#define		STATE_STABLE		5			/* Stable lighting */

/*----- Counter value for lamp ignition process -----*/
#define 	COUNT_BOOST_FAIL	50			/* (value)*10[ms] : boost time limit */
#define 	COUNT_DIM_PREHEAT	40			/* (value)*10[ms] : preheat time */
#define 	COUNT_DIM_SWEEP		10			/* (value)*10[ms] : frequency sweep time */
#define 	COUNT_DIM_STABLE	50			/* (value)*10[ms] : wait time for stable lighting */

/*========================================================================
	Flag state
========================================================================*/
#define		ON					1			/* Flag setting state */
#define		OFF					0			/* Flag clear state */
